==> zio-aws-appsync_2.12-5.17.171.1-sources.jar: zio/aws/appsync/model/UpdateTypeResponse.scala <==
package zio.aws.appsync.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateTypeResponse(
    `type`: Optional[zio.aws.appsync.model.Type] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.UpdateTypeResponse = {
    import UpdateTypeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.UpdateTypeResponse
      .builder()
      .optionallyWith(`type`.map(value => value.buildAwsValue()))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.appsync.model.UpdateTypeResponse.ReadOnly =
    zio.aws.appsync.model.UpdateTypeResponse.wrap(buildAwsValue())
}
object UpdateTypeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.UpdateTypeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.UpdateTypeResponse =
      zio.aws.appsync.model
        .UpdateTypeResponse(`type`.map(value => value.asEditable))
    def `type`: Optional[zio.aws.appsync.model.Type.ReadOnly]
    def getType: ZIO[Any, AwsError, zio.aws.appsync.model.Type.ReadOnly] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.UpdateTypeResponse
  ) extends zio.aws.appsync.model.UpdateTypeResponse.ReadOnly {
    override val `type`: Optional[zio.aws.appsync.model.Type.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.appsync.model.Type.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.UpdateTypeResponse
  ): zio.aws.appsync.model.UpdateTypeResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appsync_2.13-5.17.115.1-sources.jar: zio/aws/appsync/model/UpdateTypeResponse.scala <==
package zio.aws.appsync.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateTypeResponse(
    `type`: Option[zio.aws.appsync.model.Type] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.UpdateTypeResponse = {
    import UpdateTypeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.UpdateTypeResponse
      .builder()
      .optionallyWith(`type`.map(value => value.buildAwsValue()))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.appsync.model.UpdateTypeResponse.ReadOnly =
    zio.aws.appsync.model.UpdateTypeResponse.wrap(buildAwsValue())
}
object UpdateTypeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.UpdateTypeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.UpdateTypeResponse =
      zio.aws.appsync.model
        .UpdateTypeResponse(`type`.map(value => value.asEditable))
    def `type`: Option[zio.aws.appsync.model.Type.ReadOnly]
    def getType: ZIO[Any, AwsError, zio.aws.appsync.model.Type.ReadOnly] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.UpdateTypeResponse
  ) extends zio.aws.appsync.model.UpdateTypeResponse.ReadOnly {
    override val `type`: Option[zio.aws.appsync.model.Type.ReadOnly] = scala
      .Option(impl.`type`())
      .map(value => zio.aws.appsync.model.Type.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.UpdateTypeResponse
  ): zio.aws.appsync.model.UpdateTypeResponse.ReadOnly = new Wrapper(impl)
}
